|
|
remap |
The home page of REBASE is: http://rebase.neb.com/
This program uses REBASE data to find the recognition sites and/or cut sites of restriction enzymes in a nucleic acid sequence.
This program displays the cut sites on both strands by default. It will optionally also display the translation of the sequence.
There are many options to change the style of display to aid in making clear presentations.
One potentially very useful option is '-flatreformat' that displays not only the cut sites which many other restriction cut-site programs will show, but also shows the recognition site.
This example uses only a small region of the input sequence to save space.
% remap -notran -sbeg 1 -send 60 Display a sequence with restriction cut sites, translation etc.. Input sequence(s): tembl:eclac Comma separated enzyme list [all]: taqi,bsu6i,acii,bsski Minimum recognition site length [4]: Output file [eclac.remap]: |
Go to the input files for this example
Go to the output files for this example
Example 2
This is an example where all enzymes in the REBASE database are used:
% remap -notran -sbeg 1 -send 60 Display a sequence with restriction cut sites, translation etc.. Input sequence(s): tembl:eclac Comma separated enzyme list [all]: Minimum recognition site length [4]: Output file [eclac.remap]: |
Go to the output files for this example
Example 3
This shows the 'flat' format:
% remap -notran -sbeg 1 -send 60 -flat Display a sequence with restriction cut sites, translation etc.. Input sequence(s): tembl:eclac Comma separated enzyme list [all]: Minimum recognition site length [4]: Output file [eclac.remap]: |
Go to the output files for this example
Mandatory qualifiers:
[-sequence] seqall Sequence database USA
-enzymes string The name 'all' reads in all enzyme names
from the REBASE database. You can specify
enzymes by giving their names with commas
between then, such as:
'HincII,hinfI,ppiI,hindiii'.
The case of the names is not important. You
can specify a file of enzyme names to read
in by giving the name of the file holding
the enzyme names with a '@' character in
front of it, for example, '@enz.list'.
Blank lines and lines starting with a hash
character or '!' are ignored and all other
lines are concatenated together with a comma
character ',' and then treated as the list
of enzymes to search for.
An example of a file of enzyme names is:
! my enzymes
HincII, ppiII
! other enzymes
hindiii
HinfI
PpiI
-sitelen integer Minimum recognition site length
[-outfile] outfile If you enter the name of a file here then
this program will write the sequence details
into that file.
Optional qualifiers:
-mincuts integer Minimum cuts per RE
-maxcuts integer Maximum cuts per RE
-single boolean Force single site only cuts
-[no]blunt boolean Allow blunt end cutters
-[no]sticky boolean Allow sticky end cutters
-[no]ambiguity boolean Allow ambiguous matches
-plasmid boolean Allow circular DNA
-[no]commercial boolean Only enzymes with suppliers
-table menu Code to use
-[no]cutlist boolean List the enzymes that cut
-flatreformat boolean Display RE sites in flat format
-[no]limit boolean Limits reports to one isoschizomer
-preferred boolean Report preferred isoschizomers
Advanced qualifiers:
-[no]translation boolean Display translation
-[no]reverse boolean Display cut sites and translation of reverse
sense
-orfminsize integer Minimum size of Open Reading Frames (ORFs)
to display in the translations.
-uppercase range Regions to put in uppercase.
If this is left blank, then the sequence
case is left alone.
A set of regions is specified by a set of
pairs of positions.
The positions are integers.
They are separated by any non-digit,
non-alpha character.
Examples of region specifications are:
24-45, 56-78
1:45, 67=99;765..888
1,5,8,10,23,45,57,99
-highlight range Regions to colour if formatting for HTML.
If this is left blank, then the sequence is
left alone.
A set of regions is specified by a set of
pairs of positions.
The positions are integers.
They are followed by any valid HTML font
colour.
Examples of region specifications are:
24-45 blue 56-78 orange
1-100 green 120-156 red
A file of ranges to colour (one range per
line) can be specifed as '@filename'.
-threeletter boolean Display protein sequences in three-letter
code
-number boolean Number the sequences
-width integer Width of sequence to display
-length integer Line length of page (0 for indefinite)
-margin integer Margin around sequence for numbering
-[no]name boolean Set this to be false if you do not wish to
display the ID name of the sequence
-[no]description boolean Set this to be false if you do not wish to
display the description of the sequence
-offset integer Offset to start numbering the sequence from
-html boolean Use HTML formatting
General qualifiers:
-help boolean Report command line options. More
information on associated and general
qualifiers can be found with -help -verbose
|
| Mandatory qualifiers | Allowed values | Default | |||||||||||||||||||||||||||||||||||||
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
| [-sequence] (Parameter 1) |
Sequence database USA | Readable sequence(s) | Required | ||||||||||||||||||||||||||||||||||||
| -enzymes | The name 'all' reads in all enzyme names from the REBASE database. You can specify enzymes by giving their names with commas between then, such as: 'HincII,hinfI,ppiI,hindiii'. The case of the names is not important. You can specify a file of enzyme names to read in by giving the name of the file holding the enzyme names with a '@' character in front of it, for example, '@enz.list'. Blank lines and lines starting with a hash character or '!' are ignored and all other lines are concatenated together with a comma character ',' and then treated as the list of enzymes to search for. An example of a file of enzyme names is: ! my enzymes HincII, ppiII ! other enzymes hindiii HinfI PpiI | Any string is accepted | all | ||||||||||||||||||||||||||||||||||||
| -sitelen | Minimum recognition site length | Integer from 2 to 20 | 4 | ||||||||||||||||||||||||||||||||||||
| [-outfile] (Parameter 2) |
If you enter the name of a file here then this program will write the sequence details into that file. | Output file | <sequence>.remap | ||||||||||||||||||||||||||||||||||||
| Optional qualifiers | Allowed values | Default | |||||||||||||||||||||||||||||||||||||
| -mincuts | Minimum cuts per RE | Integer from 1 to 1000 | 1 | ||||||||||||||||||||||||||||||||||||
| -maxcuts | Maximum cuts per RE | Integer up to 2000000000 | 2000000000 | ||||||||||||||||||||||||||||||||||||
| -single | Force single site only cuts | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| -[no]blunt | Allow blunt end cutters | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -[no]sticky | Allow sticky end cutters | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -[no]ambiguity | Allow ambiguous matches | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -plasmid | Allow circular DNA | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| -[no]commercial | Only enzymes with suppliers | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -table | Code to use |
|
0 | ||||||||||||||||||||||||||||||||||||
| -[no]cutlist | List the enzymes that cut | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -flatreformat | Display RE sites in flat format | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| -[no]limit | Limits reports to one isoschizomer | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -preferred | Report preferred isoschizomers | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| Advanced qualifiers | Allowed values | Default | |||||||||||||||||||||||||||||||||||||
| -[no]translation | Display translation | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -[no]reverse | Display cut sites and translation of reverse sense | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -orfminsize | Minimum size of Open Reading Frames (ORFs) to display in the translations. | Integer 0 or more | 0 | ||||||||||||||||||||||||||||||||||||
| -uppercase | Regions to put in uppercase. If this is left blank, then the sequence case is left alone. A set of regions is specified by a set of pairs of positions. The positions are integers. They are separated by any non-digit, non-alpha character. Examples of region specifications are: 24-45, 56-78 1:45, 67=99;765..888 1,5,8,10,23,45,57,99 | Sequence range | If this is left blank, then the sequence case is left alone. | ||||||||||||||||||||||||||||||||||||
| -highlight | Regions to colour if formatting for HTML. If this is left blank, then the sequence is left alone. A set of regions is specified by a set of pairs of positions. The positions are integers. They are followed by any valid HTML font colour. Examples of region specifications are: 24-45 blue 56-78 orange 1-100 green 120-156 red A file of ranges to colour (one range per line) can be specifed as '@filename'. | Sequence range | full sequence | ||||||||||||||||||||||||||||||||||||
| -threeletter | Display protein sequences in three-letter code | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| -number | Number the sequences | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
| -width | Width of sequence to display | Integer 1 or more | 60 | ||||||||||||||||||||||||||||||||||||
| -length | Line length of page (0 for indefinite) | Integer 0 or more | 0 | ||||||||||||||||||||||||||||||||||||
| -margin | Margin around sequence for numbering | Integer 0 or more | 10 | ||||||||||||||||||||||||||||||||||||
| -[no]name | Set this to be false if you do not wish to display the ID name of the sequence | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -[no]description | Set this to be false if you do not wish to display the description of the sequence | Boolean value Yes/No | Yes | ||||||||||||||||||||||||||||||||||||
| -offset | Offset to start numbering the sequence from | Any integer value | 1 | ||||||||||||||||||||||||||||||||||||
| -html | Use HTML formatting | Boolean value Yes/No | No | ||||||||||||||||||||||||||||||||||||
ID ECLAC standard; DNA; PRO; 7477 BP.
XX
AC J01636; J01637; K01483; K01793;
XX
SV J01636.1
XX
DT 30-NOV-1990 (Rel. 26, Created)
DT 04-MAR-2000 (Rel. 63, Last updated, Version 7)
XX
DE E.coli lactose operon with lacI, lacZ, lacY and lacA genes.
XX
KW acetyltransferase; beta-D-galactosidase; galactosidase; lac operon;
KW lac repressor protein; lacA gene; lacI gene; lactose permease; lacY gene;
KW lacZ gene; mutagenesis; palindrome; promoter region;
KW thiogalactoside acetyltransferase.
XX
OS Escherichia coli
OC Bacteria; Proteobacteria; gamma subdivision; Enterobacteriaceae;
OC Escherichia.
XX
RN [1]
RP 1243-1266
RX MEDLINE; 74055539.
RA Gilbert W., Maxam A.;
RT "The nucleotide sequence of the lac operator";
RL Proc. Natl. Acad. Sci. U.S.A. 70:3581-3584(1973).
XX
RN [2]
RP 1246-1308
RX MEDLINE; 74055540.
RA Maizels N.M.;
RT "The nucleotide sequence of the lactose messenger ribonucleic acid
RT transcribed from the UV5 promoter mutant of Escherichia coli";
RL Proc. Natl. Acad. Sci. U.S.A. 70:3585-3589(1973).
XX
RN [3]
RX MEDLINE; 74174501.
RA Gilbert W., Maizels N., Maxam A.;
RT "Sequences of controlling regions of the lactose operon";
RL Cold Spring Harb. Symp. Quant. Biol. 38:845-855(1974).
XX
RN [4]
RA Gilbert W., Gralla J., Majors A.J., Maxam A.;
RT "Lactose operator sequences and the action of lac repressor";
RL (in) Sund H., Blauer G. (eds.);
RL PROTEIN-LIGAND INTERACTIONS:193-207;
RL Walter de Gruyter, New York (1975)
XX
RN [5]
RP 1146-1282
[Part of this file has been deleted for brevity]
cgatttggct acatgacatc aaccatatca gcaaaagtga tacgggtatt atttttgccg 4560
ctatttctct gttctcgcta ttattccaac cgctgtttgg tctgctttct gacaaactcg 4620
ggctgcgcaa atacctgctg tggattatta ccggcatgtt agtgatgttt gcgccgttct 4680
ttatttttat cttcgggcca ctgttacaat acaacatttt agtaggatcg attgttggtg 4740
gtatttatct aggcttttgt tttaacgccg gtgcgccagc agtagaggca tttattgaga 4800
aagtcagccg tcgcagtaat ttcgaatttg gtcgcgcgcg gatgtttggc tgtgttggct 4860
gggcgctgtg tgcctcgatt gtcggcatca tgttcaccat caataatcag tttgttttct 4920
ggctgggctc tggctgtgca ctcatcctcg ccgttttact ctttttcgcc aaaacggatg 4980
cgccctcttc tgccacggtt gccaatgcgg taggtgccaa ccattcggca tttagcctta 5040
agctggcact ggaactgttc agacagccaa aactgtggtt tttgtcactg tatgttattg 5100
gcgtttcctg cacctacgat gtttttgacc aacagtttgc taatttcttt acttcgttct 5160
ttgctaccgg tgaacagggt acgcgggtat ttggctacgt aacgacaatg ggcgaattac 5220
ttaacgcctc gattatgttc tttgcgccac tgatcattaa tcgcatcggt gggaaaaacg 5280
ccctgctgct ggctggcact attatgtctg tacgtattat tggctcatcg ttcgccacct 5340
cagcgctgga agtggttatt ctgaaaacgc tgcatatgtt tgaagtaccg ttcctgctgg 5400
tgggctgctt taaatatatt accagccagt ttgaagtgcg tttttcagcg acgatttatc 5460
tggtctgttt ctgcttcttt aagcaactgg cgatgatttt tatgtctgta ctggcgggca 5520
atatgtatga aagcatcggt ttccagggcg cttatctggt gctgggtctg gtggcgctgg 5580
gcttcacctt aatttccgtg ttcacgctta gcggccccgg cccgctttcc ctgctgcgtc 5640
gtcaggtgaa tgaagtcgct taagcaatca atgtcggatg cggcgcgacg cttatccgac 5700
caacatatca taacggagtg atcgcattga acatgccaat gaccgaaaga ataagagcag 5760
gcaagctatt taccgatatg tgcgaaggct taccggaaaa aagacttcgt gggaaaacgt 5820
taatgtatga gtttaatcac tcgcatccat cagaagttga aaaaagagaa agcctgatta 5880
aagaaatgtt tgccacggta ggggaaaacg cctgggtaga accgcctgtc tatttctctt 5940
acggttccaa catccatata ggccgcaatt tttatgcaaa tttcaattta accattgtcg 6000
atgactacac ggtaacaatc ggtgataacg tactgattgc acccaacgtt actctttccg 6060
ttacgggaca ccctgtacac catgaattga gaaaaaacgg cgagatgtac tcttttccga 6120
taacgattgg caataacgtc tggatcggaa gtcatgtggt tattaatcca ggcgtcacca 6180
tcggggataa ttctgttatt ggcgcgggta gtatcgtcac aaaagacatt ccaccaaacg 6240
tcgtggcggc tggcgttcct tgtcgggtta ttcgcgaaat aaacgaccgg gataagcact 6300
attatttcaa agattataaa gttgaatcgt cagtttaaat tataaaaatt gcctgatacg 6360
ctgcgcttat caggcctaca agttcagcga tctacattag ccgcatccgg catgaacaaa 6420
gcgcaggaac aagcgtcgca tcatgcctct ttgacccaca gctgcggaaa acgtactggt 6480
gcaaaacgca gggttatgat catcagccca acgacgcaca gcgcatgaaa tgcccagtcc 6540
atcaggtaat tgccgctgat actacgcagc acgccagaaa accacggggc aagcccggcg 6600
atgataaaac cgattccctg cataaacgcc accagcttgc cagcaatagc cggttgcaca 6660
gagtgatcga gcgccagcag caaacagagc ggaaacgcgc cgcccagacc taacccacac 6720
accatcgccc acaataccgg caattgcatc ggcagccaga taaagccgca gaaccccacc 6780
agttgtaaca ccagcgccag cattaacagt ttgcgccgat cctgatggcg agccatagca 6840
ggcatcagca aagctcctgc ggcttgccca agcgtcatca atgccagtaa ggaaccgctg 6900
tactgcgcgc tggcaccaat ctcaatatag aaagcgggta accaggcaat caggctggcg 6960
taaccgccgt taatcagacc gaagtaaaca cccagcgtcc acgcgcgggg agtgaatacc 7020
acgcgaaccg gagtggttgt tgtcttgtgg gaagaggcga cctcgcgggc gctttgccac 7080
caccaggcaa agagcgcaac aacggcaggc agcgccacca ggcgagtgtt tgataccagg 7140
tttcgctatg ttgaactaac cagggcgtta tggcggcacc aagcccaccg ccgcccatca 7200
gagccgcgga ccacagcccc atcaccagtg gcgtgcgctg ctgaaaccgc cgtttaatca 7260
ccgaagcatc accgcctgaa tgatgccgat ccccacccca ccaagcagtg cgctgctaag 7320
cagcagcgca ctttgcgggt aaagctcacg catcaatgca ccgacggcaa tcagcaacag 7380
actgatggcg acactgcgac gttcgctgac atgctgatga agccagcttc cggccagcgc 7440
cagcccgccc atggtaacca ccggcagagc ggtcgac 7477
//
|
You can specifiy a file of ranges to display in uppercase by giving the '-uppercase' qualifier the value '@' followed by the name of the file containing the ranges. (eg: '-upper @myfile').
The format of the range file is:
An example range file is:
# this is my set of ranges 12 23 4 5 this is like 12-23, but smaller 67 10348 interesting region
You can specifiy a file of ranges to highlight in a different colour when outputting in HTML format (using the '-html' qualifier) by giving the '-highlight' qualifier the value '@' followed by the name of the file containing the ranges. (eg: '-highlight @myfile').
The format of this file is very similar to the format of the above uppercase range file, except that the text after the start and end positions is used as the HTML colour name. This colour name is used 'as is' when specifying the colour in HTML in a '<FONT COLOR=xxx>' construct, (where 'xxx' is the name of the colour).
The standard names of HTML font colours are given in:
http://http://www.w3.org/TR/REC-html40/types.html
and
http://www.ausmall.com.au/freegraf/ncolour2.htm
and
http://mindprod.com/htmlcolours.html
(amongst other places).
An example highlight range file is:
# this is my set of ranges 12 23 red 4 5 darkturquoise 67 10348 #FFE4E1
ECLAC
E.coli lactose operon with lacI, lacZ, lacY and lacA genes.
Bsu6I
TaqI AciI BssKI
\ \ \
GACACCATCGAATGGCGCAAAACCTTTCGCGGTATGGCATGATAGCGCCCGGAAGAGAGT
10 20 30 40 50 60
----:----|----:----|----:----|----:----|----:----|----:----|
CTGTGGTAGCTTACCGCGTTTTGGAAAGCGCCATACCGTACTATCGCGGGCCTTCTCTCA
/ / / /
TaqI AciI | BssKI
Bsu6I
# Enzymes that cut Frequency Isoschizomers
AciI 1
BssKI 1
Bsu6I 1
TaqI 1
# Enzymes < MINCUTS Frequency Isoschizomers
# Enzymes > MAXCUTS Frequency Isoschizomers
# Enzymes that do not cut
# Number of enzymes not matching SITELEN, BLUNT, STICKY, COMMERCIAL criteria
0
|
ECLAC
E.coli lactose operon with lacI, lacZ, lacY and lacA genes.
Hin6I
TaqI | HhaI
| Bsc4I | Bsu6I
| | Hin6I | BssKI
| | | HhaI AciI | | BsiSI
\ \ \ \ \ \ \ \
GACACCATCGAATGGCGCAAAACCTTTCGCGGTATGGCATGATAGCGCCCGGAAGAGAGT
10 20 30 40 50 60
----:----|----:----|----:----|----:----|----:----|----:----|
CTGTGGTAGCTTACCGCGTTTTGGAAAGCGCCATACCGTACTATCGCGGGCCTTCTCTCA
/ / / / / / / ///
| TaqI | Hin6I AciI | | ||BssKI
Bsc4I HhaI | | |BsiSI
| | Bsu6I
| Hin6I
HhaI
# Enzymes that cut Frequency Isoschizomers
AciI 1
Bsc4I 1
BsiSI 1
BssKI 1
Bsu6I 1
HhaI 2
Hin6I 2 HinP1I,HspAI
TaqI 1
# Enzymes < MINCUTS Frequency Isoschizomers
# Enzymes > MAXCUTS Frequency Isoschizomers
# Enzymes that do not cut
AclI BamHI BceAI Bse1I BshI ClaI EcoRI EcoRII
Hin4I HindII HindIII HpyCH4IV KpnI NotI
# Number of enzymes not matching SITELEN, BLUNT, STICKY, COMMERCIAL criteria
0
|
ECLAC
E.coli lactose operon with lacI, lacZ, lacY and lacA genes.
Bsu6I
>.........====
BsiSI
>===
HhaI BssKI
==>= >=====
TaqI Hin6I HhaI
>=== >=== ==>=
Bsc4I AciI Hin6I
======>==== >..==== >===
GACACCATCGAATGGCGCAAAACCTTTCGCGGTATGGCATGATAGCGCCCGGAAGAGAGT
10 20 30 40 50 60
----:----|----:----|----:----|----:----|----:----|----:----|
CTGTGGTAGCTTACCGCGTTTTGGAAAGCGCCATACCGTACTATCGCGGGCCTTCTCTCA
====<====== <=== ===<
Bsc4I AciI Hin6I
===< ===< =<== <.....====
TaqI Hin6I HhaI Bsu6I
=<== =====<
HhaI BssKI
===<
BsiSI
# Enzymes that cut Frequency Isoschizomers
AciI 1
Bsc4I 1
BsiSI 1
BssKI 1
Bsu6I 1
HhaI 2
Hin6I 2 HinP1I,HspAI
TaqI 1
# Enzymes < MINCUTS Frequency Isoschizomers
# Enzymes > MAXCUTS Frequency Isoschizomers
# Enzymes that do not cut
AclI BamHI BceAI Bse1I BshI ClaI EcoRI EcoRII
Hin4I HindII HindIII HpyCH4IV KpnI NotI
# Number of enzymes not matching SITELEN, BLUNT, STICKY, COMMERCIAL criteria
0
|
The name of the sequence is displayed, followed by the description of the sequence.
The formatted display of cut sites on the sequence follows, with the six-frame translation below it. The cut sites are indicated by a slash character '\' that points to the poition between the nucleotides where the cuts occur. Cuts by many enzymes at the same position are indicated by stacking the enzyme names on top of each other.
At the end the section header 'Enzymes that cut' is displayed followed by a list of the enzymes that cut the specified sequence and the number of times that they cut. For each enzyme that cuts, a list of isoschizomers of that enzyme (sharing the same recognition site pattern and cut sites) is given.
This is followed by lists of the enzymes that do cut, but which cut less often than the '-mincut' qualifier or more often than the '-maxcut' qualifier.
Any of the isoschizomers that are excluded from cutting, (either through restrictions such as the permitted number of cuts, blunt cutters only, single cutters only etc. or because their name has not been given in the input list of enzymes), will not be listed.
Then a list is displayed of the enzymes whose names were input and which match the other criteria ('-sitelen', '-blunt', '-sticky' or '-commercial') but which do not cut.
Finally the number of enzymes that were rejected from consideration because they do not match the '-sitelen', '-blunt', '-sticky' or '-commercial' criteria is displayed.
The '-flatreformat' qualifier changes the display to emphasise the recognition site of the restriction enzyme, which is indicated by a row of '=' characters. The cut site if pointed to by a '>' or '<' character and if the cut site is not within or imemdiately adjacent to the recognition site, they are linked by a row or '.' characters.
The name of the enzyme is displayed above (or below when the reverse sense site if displayed) the recognition site. The name of the enzyme is also displayed above the cut site if this occurs on a different display line to the recognition site (i.e. if it wraps onto the next line of sequence).
These files must first be set up using the program 'rebaseextract'. Running 'rebaseextract' may be the job of your system manager.
| Program name | Description |
|---|---|
| abiview | Reads ABI file and display the trace |
| backtranseq | Back translate a protein sequence |
| cirdna | Draws circular maps of DNA constructs |
| coderet | Extract CDS, mRNA and translations from feature tables |
| lindna | Draws linear maps of DNA constructs |
| pepnet | Displays proteins as a helical net |
| pepwheel | Shows protein sequences as helices |
| plotorf | Plot potential open reading frames |
| prettyplot | Displays aligned sequences, with colouring and boxing |
| prettyseq | Output sequence with translated ranges |
| recoder | Remove restriction sites but maintain the same translation |
| redata | Search REBASE for enzyme name, references, suppliers etc |
| restover | Finds restriction enzymes that produce a specific overhang |
| restrict | Finds restriction enzyme cleavage sites |
| seealso | Finds programs sharing group names |
| showalign | Displays a multiple sequence alignment |
| showdb | Displays information on the currently available databases |
| showfeat | Show features of a sequence |
| showorf | Pretty output of DNA translations |
| showseq | Display a sequence with features, translation etc |
| silent | Silent mutation restriction enzyme scan |
| sixpack | Display a DNA sequence with 6-frame translation and ORFs |
| textsearch | Search sequence documentation text. SRS and Entrez are faster! |
| transeq | Translate nucleic acid sequences |
Changed 7 Dec 2000 - GWW - to declare isoschizomers that cut